netapp_ontap.models.volume_encryption API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.volume_encryption`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class VolumeEncryptionSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the VolumeEncryption object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `enabled GET POST PATCH`

    Creates an encrypted or an unencrypted volume. For POST, when set to 'true', a new key is generated and used to encrypt the given volume. In that case, the underlying SVM must be configured with the key manager. When set to 'false', the volume created will be unencrypted. For PATCH, when set to 'true', it encrypts an unencrypted volume. Specifying the parameter as 'false' in a PATCH operation for an encrypted volume is only supported when moving the volume to another aggregate.

  `key_id GET`

    The key ID used for creating encrypted volume. A new key-id is generated for creating an encrypted volume. This key-id is associated with the generated key.

  `rekey GET PATCH`

    If set to 'true', re-encrypts the volume with a new key. Valid in PATCH.

  `state GET`

    Volume encryption state.
    encrypted ‐ The volume is completely encrypted.
    encrypting ‐ Encryption operation is in progress.
    partial ‐ Some constituents are encrypted and some are not. Applicable only for FlexGroup volume.
    rekeying. Encryption of volume with a new key is in progress.
    unencrypted ‐ The volume is a plain-text one.

    Valid choices:

    - encrypted
    - encrypting
    - partial
    - rekeying
    - unencrypted
  `status GET POST PATCH`

    The status field of the volume_encryption.

  `type GET`

    Volume encryption type.
    none ‐ The volume is a plain-text one.
    volume ‐ The volume is encrypted with NVE (NetApp Volume Encryption).
    aggregate ‐ The volume is encrypted with NAE (NetApp Aggregate Encryption).

    Valid choices:

    - none
    - volume
    - aggregate